@@ -23,7 +23,6 @@ import imp
 import os
 
 import six
-
 from ansible import constants
 from ansible.errors import AnsibleError
 
@@ -77,9 +76,9 @@ FILENAME_KEY = '__file__'
 
 VALID_KEYS = [
     'name', 'action', 'when', 'async', 'poll', 'notify',
-    'first_available_file', 'include', 'tags', 'register', 'ignore_errors',
-    'delegate_to', 'local_action', 'transport', 'remote_user', 'sudo', 'sudo_user',
-    'sudo_pass', 'when', 'connection', 'environment', 'args', 'always_run',
+    'first_available_file', 'include', 'include_tasks', 'import_tasks', 'tags', 'register',
+    'ignore_errors', 'delegate_to', 'local_action', 'transport', 'remote_user', 'sudo',
+    'sudo_user', 'sudo_pass', 'when', 'connection', 'environment', 'args', 'always_run',
     'any_errors_fatal', 'changed_when', 'failed_when', 'check_mode', 'delay', 'retries', 'until',
     'su', 'su_user', 'su_pass', 'no_log', 'run_once',
     'become', 'become_user', 'become_method', FILENAME_KEY,
@@ -193,6 +192,8 @@ def play_children(basedir, item, parent_type, playbook_dir):
         'post_tasks': _taskshandlers_children,
         'block': _taskshandlers_children,
         'include': _include_children,
+        'include_tasks': _include_children,
+        'import_tasks': _include_children,
         'roles': _roles_children,
         'dependencies': _roles_children,
         'handlers': _taskshandlers_children,
@@ -225,27 +226,34 @@ def _taskshandlers_children(basedir, k, v, parent_type):
     results = []
     for th in v:
         if 'include' in th:
-            # when taskshandlers_children is called for playbooks, the
-            # actual type of the included tasks is the section containing the
-            # include, e.g. tasks, pre_tasks, or handlers.
-            if parent_type == 'playbook':
-                playbook_section = k
-            else:
-                playbook_section = parent_type
-            results.append({
-                'path': path_dwim(basedir, th['include']),
-                'type': playbook_section
-            })
+            append_children(th['include'], basedir, k, parent_type, results)
+        elif 'include_tasks' in th:
+            append_children(th['include_tasks'], basedir, k, parent_type, results)
+        elif 'import_tasks' in th:
+            append_children(th['import_tasks'], basedir, k, parent_type, results)
         elif 'block' in th:
             results.extend(_taskshandlers_children(basedir, k, th['block'], parent_type))
             if 'rescue' in th:
                 results.extend(_taskshandlers_children(basedir, k, th['rescue'], parent_type))
             if 'always' in th:
                 results.extend(_taskshandlers_children(basedir, k, th['always'], parent_type))
-
     return results
 
 
+def append_children(taskhandler, basedir, k, parent_type, results):
+    # when taskshandlers_children is called for playbooks, the
+    # actual type of the included tasks is the section containing the
+    # include, e.g. tasks, pre_tasks, or handlers.
+    if parent_type == 'playbook':
+        playbook_section = k
+    else:
+        playbook_section = parent_type
+    results.append({
+        'path': path_dwim(basedir, taskhandler),
+        'type': playbook_section
+    })
+
+
 def _roles_children(basedir, k, v, parent_type):
     results = []
     for role in v:
@@ -442,9 +450,9 @@ def task_to_str(task):
     if name:
         return name
     action = task.get("action")
-    args = " " .join([u"{0}={1}".format(k, v) for (k, v) in action.items()
+    args = " ".join([u"{0}={1}".format(k, v) for (k, v) in action.items()
                      if k not in ["__ansible_module__", "__ansible_arguments__"]] +
-                     action.get("__ansible_arguments__"))
+                    action.get("__ansible_arguments__"))
     return u"{0} {1}".format(action["__ansible_module__"], args)
 
 
@@ -483,7 +491,8 @@ def get_action_tasks(yaml, file):
     block_rescue_always = ('block', 'rescue', 'always')
     tasks[:] = [task for task in tasks if all(k not in task for k in block_rescue_always)]
 
-    return [task for task in tasks if 'include' not in task.keys()]
+    return [task for task in tasks if
+            {'include', 'include_tasks', 'import_tasks'}.isdisjoint(task.keys())]
 
 
 def get_normalized_tasks(yaml, file):
